# wumpus.py
An asynchronous wrapper around Discord's API.  

## This project isn't finished yet!
This package is far from finished right now - 
there's still a lot to cover. We're trying our best though.
